javascript:
	/* Check if CaptchaBoo9kw class is available */
	if (typeof CaptchaBoo9kw !== 'function') {
		function CaptchaBoo9kw() {
			/* Enter your 9kw API key */
			API_KEY_9KW = 'YOUR_9KW_API_KEY';
			API_URL = 'https://www.9kw.eu/index.cgi';
			
			CAPTCHA_SOLVE_TIMEOUT_SEC = 600;
			this.CAPTCHA_SOLVE_CHECK_PERIOD_SEC = 5;

			captchaIframe = null;
			captchaResponseFormField = null;
			captchaSolvingStatusElement = null;

			COLOR_RED = 1;
			COLOR_YELLOW = 2;
			COLOR_GREEN = 3;
			
			/* Set DEBUG to true to enable more detailed logs */
			DEBUG = false;

			this.id = 0;
			this.intervalObj = null;

			LOG_LABEL = '[CaptchaBoo] ';
			
			MSG_CAPTCHA_EXPIRED = 'Captcha solving has expired';
			MSG_CAPTCHA_RESPONSE_FIELD_NOT_FOUND = 'Captcha response form field not found';
			MSG_CAPTCHA_NOT_FOUND = 'No captcha found';
			MSG_CAPTCHA_SOLVING_STATUS_UPDATE = 'Update captcha solving status';
			MSG_CAPTCHA_SOLVED = 'Captcha solved';
			MSG_CAPTCHA_WAITS = 'Captcha waits to be solved';
			MSG_COLOR_UNKNOWN = 'Unknown captcha color. Assuming red.';

			xmlHttp = new XMLHttpRequest();

			this.checkIfCaptchaIsSolved = function () {
				var id = this.id;

				if (id == 0) {
					this.loge('Captcha ID = 0');
					return;
				}

				var responseFormField = document.getElementById('g-recaptcha-response');

				var data = {
					action: 'usercaptchacorrectdata',
					apikey: API_KEY_9KW,
					id: id,
					json: '1',
				};
				var checkUrl = API_URL + '?' + encodeQueryData(data);

				var response = doGet(checkUrl);

				if (DEBUG)
					this.log('Response: ' + response);

				var json = JSON.parse(response);

				if (json.answer == '') {
					if (DEBUG)
						this.log(MSG_CAPTCHA_WAITS);

					colorCaptcha(COLOR_YELLOW);
					return;
				}

				else if (json.answer == null) {
					if (DEBUG)
						this.log(MSG_CAPTCHA_EXPIRED);
						
					colorCaptcha(COLOR_RED);

					this.stopCheckingThread();
						
					return;
				}

				responseFormField.value = json.answer;

				if (DEBUG)
					this.log(MSG_CAPTCHA_SOLVED);

				colorCaptcha(COLOR_GREEN);

				this.stopCheckingThread();
			};

			colorCaptcha = function (colorIndex) {
				var imgAlt;
				var imgSrc;

				if (colorIndex != COLOR_RED && colorIndex != COLOR_YELLOW && colorIndex != COLOR_GREEN) {
					if (DEBUG)
						log(MSG_COLOR_UNKNOWN);

					colorIndex = COLOR_RED;
				}

				/* Red */
				if (colorIndex == COLOR_RED) {
					if (DEBUG)
						this.log('Captcha color: RED');

					captchaSolvingStatusElement.style['background-color'] = 'red !important';
					imgSrc = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAIAAACQd1PeAAAACXBIWXMAAA7EAAAOxAGVKw4bAAAADElEQVQImWP4z8AAAAMBAQCc479ZAAAAAElFTkSuQmCC';
					imgAlt = 'Error occured';
				}

				/* Yellow */
				else if (colorIndex == COLOR_YELLOW) {
					if (DEBUG)
						this.log('Captcha color: YELLOW');

					captchaSolvingStatusElement.style['background-color'] = 'yellow !important';
					imgSrc = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAIAAACQd1PeAAAACXBIWXMAAA7EAAAOxAGVKw4bAAAADElEQVQImWP4/58BAAT/Af8IYC8xAAAAAElFTkSuQmCC';
					imgAlt = 'Waits to be solved';
				}

				/* Green */
				else if (colorIndex == COLOR_GREEN) {
					if (DEBUG)
						this.log('Captcha color: GREEN');

					captchaSolvingStatusElement.style['background-color'] = 'green !important';
					imgSrc = 'data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAIAAACQd1PeAAAACXBIWXMAAA7EAAAOxAGVKw4bAAAADElEQVQImWNg+M8IAAIDAQG0gnQCAAAAAElFTkSuQmCC';
					imgAlt = 'Done';
				}

				var imgStyle = 'height: 100%; width: 100%; margin: 0; padding: 0;';
				var img = '<img width=100% height=100% src="' + imgSrc + '" style = "' + imgStyle + '" alt="' + imgAlt + '"/>';
				var src = '<a href="javascript:captcha_9kw_dnoiahow8ed8uo9wd98.checkIfCaptchaIsSolved();">' + img + '</a>';
				captchaSolvingStatusElement.innerHTML = src;
			};

			doGet = function (url) {
				xmlHttp.open('GET', url, false);
				xmlHttp.send(null);
				return xmlHttp.responseText;
			};

			encodeQueryData = function (data) {
				var ret = [];
				for (var d in data)
					ret.push(encodeURIComponent(d) + '=' + encodeURIComponent(data[d]));
				return ret.join('&');
			};

			initializePageElements = function() {
				/* Captcha iframe */
				var captchaIframes = document.querySelectorAll('iframe[src*="recaptcha/api"]');

				if (!captchaIframes.length) {
					alert(MSG_CAPTCHA_NOT_FOUND);
					stopRunning();
				}

				captchaIframe = captchaIframes[0];

				/* Captcha solving status */
				captchaSolvingStatusElement = document.createElement('div');

				captchaSolvingStatusElement.style['position'] = 'relative';
				captchaSolvingStatusElement.height = 64;
				captchaSolvingStatusElement.width = 64;

				if (captchaIframe.height) {
					captchaSolvingStatusElement.height = captchaIframe.height;
					captchaSolvingStatusElement.style['height'] = captchaIframe.height + 'px';
				}

				if (captchaIframe.width) {
					captchaSolvingStatusElement.width = captchaIframe.width;
					captchaSolvingStatusElement.style['width'] = captchaIframe.width + 'px';
				}

				captchaIframe.parentNode.replaceChild(captchaSolvingStatusElement, captchaIframe);

				/* Captcha response form field */
				captchaResponseFormField = document.getElementById('g-recaptcha-response');

				if (!captchaResponseFormField) {
					this.log(MSG_CAPTCHA_RESPONSE_FIELD_NOT_FOUND);
					stopRunning();
				}
			};

			this.isCheckingThreadActive = function () {
				return this.intervalObj != null;
			};

			this.isOperaExtreme = function () {
				return (navigator.userAgent.indexOf('Opera Mini/') > -1) && (navigator.userAgent.indexOf('Presto/') > -1);
			};

			this.log = function (message) {
				var wholeMsg = new Date().toLocaleTimeString() + ': ' + LOG_LABEL + message;
				if (typeof window.console !== 'undefined')
					console.log(wholeMsg);
				else
					alert(wholeMsg);
			};

			this.loge = function (message) {
				this.log('Error: ' + message);
			};

			stopRunning = function() {
				this.stopCheckingThread();

				this.log('End');
				throw new Error('End');
			};

			this.stopCheckingThread = function () {
				if (this.isCheckingThreadActive())
					clearInterval(this.intervalObj);
			};

			this.submitCaptcha = function () {
				if (DEBUG)
					this.log('Submitting captcha');

				initializePageElements();

				var k = captchaIframe.src.split('k=')[1].split('&')[0];

				if (DEBUG)
					this.log('Captcha key = ' + k);

				var data = {
					action: 'usercaptchaupload',
					apikey: API_KEY_9KW,
					'file-upload-01': k,
					prio: '0',
					interactive: '1',
					json: '1',/*
					selfsolve: '1',
					debug: '1',*/
					maxtimeout: CAPTCHA_SOLVE_TIMEOUT_SEC,
					pageurl: encodeURIComponent(document.location.href),
				};
				var submitUrl = API_URL + '?' + encodeQueryData(data);

				var response = doGet(submitUrl);

				if (DEBUG)
					this.log('Response: ' + response);

				var json = JSON.parse(response);

				if (json.status.success == false || !json.captchaid) {

					if (DEBUG)
						this.loge('Submitting captcha: json.status.success is false or id = 0');

					colorCaptcha(COLOR_RED);

					stopRunning();
				}

				this.id = 0;
				this.id = json.captchaid;

				if (this.id == 0 || typeof this.id === 'undefined') {

					if (DEBUG)
						this.loge('Submitting captcha: id = 0 or id is undefined');
						
					colorCaptcha(COLOR_RED);

					stopRunning();
				}

				if (DEBUG)
					this.log('Submitting successful!');

				colorCaptcha(COLOR_YELLOW);
			};
		};
	}

if (typeof captcha_9kw_dnoiahow8ed8uo9wd98 === 'undefined') {
	var captcha_9kw_dnoiahow8ed8uo9wd98 = new CaptchaBoo9kw();
}

(function () {
	var captchaObj = captcha_9kw_dnoiahow8ed8uo9wd98;
	if (captchaObj.id == 0) {
		captchaObj.submitCaptcha();

		/* If browser supports, run checks in background */
		if (!captchaObj.isOperaExtreme() && !captchaObj.isCheckingThreadActive() && typeof setInterval === 'function')
			captchaObj.intervalObj = setInterval(function () {
				captchaObj.checkIfCaptchaIsSolved();
			}, captchaObj.CAPTCHA_SOLVE_CHECK_PERIOD_SEC * 1000);
	} else {
		if (DEBUG)
			captchaObj.log('Manual checking if captcha ID=' + captchaObj.id + ' is solved');

		captchaObj.checkIfCaptchaIsSolved();
	}
})();